@@ -2,7 +2,7 @@
 
 import socketio,pyperclip,time,argparse
 
-__version__ = "v0.0.26"
+__version__ = "v0.0.28"
 # standard Python
 sio = socketio.Client(reconnection=True, reconnection_attempts=0, reconnection_delay=5, reconnection_delay_max=60)
 @sio.event
@@ -20,9 +20,11 @@ def disconnect():
 
 @sio.on('sync')
 def on_message(data):
+    # windows下收到广播时立刻就会莫名其妙地清空剪贴板，为了解决这个问题这里延迟一点时间
+    time.sleep(0.1)
     curr_clip = pyperclip.paste()
-    if data["data"] != curr_clip:
-        pyperclip.copy(data["data"])
+    if data["clipboard_content"] != curr_clip:
+        pyperclip.copy(data["clipboard_content"])
 
 def main():
     parser = argparse.ArgumentParser(description='client for sync clipboard')
@@ -42,7 +44,6 @@ def main():
         print("new_clip:{}".format(new_clip))
         if new_clip != curr_clip:
             if not new_clip.startswith("file:///"):
-                # 一个很有意思的BUG,如果下一段代码是 sio.emit('sync',{"data":new_clip, "room":room}),在windows上剪贴板会被系统清空，但把“data”改成“data123”之类的就没事
                 sio.emit('sync',{"clipboard_content":new_clip, "room":room})
             curr_clip = new_clip
 def cli() -> None:
